==> qcad-3.5.1.0_2.txz: usr/local/share/qcad/scripts/Draw/Text/ts/Text_sl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sl_SI">
<context>
    <name>Dialog</name>
    <message>
        <location filename="../TextDialog/CharacterMapDialog.ui" line="+14"/>
        <source>Character Map</source>
        <translation>Tabela znakov</translation>
    </message>
</context>
<context>
    <name>Text</name>
    <message>
        <location filename="../Text.js" line="+88"/>
        <source>Position</source>
        <translation>Pozicija</translation>
    </message>
    <message>
        <location filename="../Text.ui" line="+17"/>
        <source>Contents:</source>
        <translation>Vsebina:</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Height:</source>
        <translation>Višina:</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Angle:</source>
        <translation>Kot:</translation>
    </message>
    <message>
        <location filename="../TextInit.js" line="+2"/>
        <source>&amp;Text</source>
        <translation>&amp;Besedilo</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Draw text</source>
        <translation>Vstavi besedilo</translation>
    </message>
</context>
<context>
    <name>TextDialog</name>
    <message>
        <location filename="../TextDialog/TextDialog.js" line="+242"/>
        <source>Default value:</source>
        <translation>Privzeta vrednost:</translation>
    </message>
    <message>
        <location line="+255"/>
        <source>&amp;Undo</source>
        <translation>Ra&amp;zveljavi</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>&amp;Redo</source>
        <translation>&amp;Obnovi</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Cu&amp;t</source>
        <translation>&amp;Izreži</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>&amp;Copy</source>
        <translation>Kop&amp;iraj</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>&amp;Paste</source>
        <translation>&amp;Prilepi</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Bold</source>
        <translation>&amp;Krepko</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>&amp;Italic</source>
        <translation>Pošev&amp;no</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>&amp;Subscript</source>
        <translation>Po&amp;dpisano</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>&amp;Superscript</source>
        <translation>&amp;Nadpisano</translation>
    </message>
    <message>
        <location line="+18"/>
        <source>&amp;Color...</source>
        <translation>Bar&amp;va...</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>&amp;Special Characters...</source>
        <translation>Posebni &amp;znaki...</translation>
    </message>
    <message>
        <location line="+310"/>
        <source>Others...</source>
        <translation>Drugo...</translation>
    </message>
    <message>
        <location line="+129"/>
        <source>Degree</source>
        <translation>Stopinje</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Plus-Minus</source>
        <translation>Plus-Minus</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Diameter</source>
        <translation>Premer</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Almost equal</source>
        <translation>Skoraj enako</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Multiplication</source>
        <translation>Moženje</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Division</source>
        <translation>Deljenje</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Delta</source>
        <translation>Delta</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Pi</source>
        <translation>Pi</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Identity</source>
        <translation>Identiteta</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Not equal</source>
        <translation>Ni enako</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Ohm</source>
        <translation>Ohm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Omega</source>
        <translation>Omega</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Squared</source>
        <translation>Kvadrirano</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Cubed</source>
        <translation>Kvadratasto</translation>
    </message>
    <message>
        <location filename="../TextDialog/TextDialog.ui" line="+14"/>
        <source>Text</source>
        <translation>Besedilo</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Main Font</source>
        <translation>Primarna pisava</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Height:</source>
        <translation>Višina:</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Text Height in Drawing Units</source>
        <translation>Višina besedila v merskih enotah risbe</translation>
    </message>
    <message>
        <location line="+18"/>
        <location line="+213"/>
        <source>Bold</source>
        <translation>Krepko</translation>
    </message>
    <message>
        <location line="-206"/>
        <location line="+219"/>
        <source>Italic</source>
        <translation>Poševno</translation>
    </message>
    <message>
        <location line="-205"/>
        <source>Text fits on one line and has no formatting</source>
        <translation>Besedilo v eni vrstici in brez oblikovanja</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Simple text
(one line, no formatting)</source>
        <translation>Preprosto besedilo
(ena vrstica, brez oblikovanja)</translation>
    </message>
    <message>
        <location line="+21"/>
        <source>Rich Text</source>
        <translation>Obogateno besedilo</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Cut</source>
        <translation>Izreži</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Copy</source>
        <translation>Kopiraj</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Paste</source>
        <translation>Prilepi</translation>
    </message>
    <message>
        <location line="+115"/>
        <source>Ctrl+B</source>
        <translation>Ctrl+B</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Ctrl+I</source>
        <translation>Ctrl+I</translation>
    </message>
    <message>
        <location line="+40"/>
        <source>Insert Symbol...</source>
        <translation>Vstavi simbol...</translation>
    </message>
    <message>
        <location line="+43"/>
        <source>Source</source>
        <translation>Vir</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>Attribute Details</source>
        <translation>Podrobnosti atributa</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Tag:</source>
        <translation>Značka:</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Prompt:</source>
        <translation>Vprašaj:</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Value:</source>
        <translation>Vrednost:</translation>
    </message>
    <message>
        <location line="+42"/>
        <source>Text Geometry</source>
        <translation>Geometrija besedila</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Line spacing factor:</source>
        <translation>Razmak med vrsticami:</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Line Spacing Factor</source>
        <translation>Faktor razmaka med vrsticami</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Angle:</source>
        <translation>Kot:</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Rotation Angle</source>
        <translation>Kot rotacije</translation>
    </message>
    <message>
        <location line="+25"/>
        <source>Alignment</source>
        <translation>Poravnava</translation>
    </message>
    <message>
        <location line="+21"/>
        <source>Bottom Left</source>
        <translation>Desno spodaj</translation>
    </message>
    <message>
        <location line="+32"/>
        <source>Bottom Center</source>
        <translation>Sredina spodaj</translation>
    </message>
    <message>
        <location line="+32"/>
        <source>Top Center</source>
        <translation>Zgoraj sredina</translation>
    </message>
    <message>
        <location line="+32"/>
        <source>Middle Right</source>
        <translation>Sredina desno</translation>
    </message>
    <message>
        <location line="+32"/>
        <source>Base Left</source>
        <translation>V izhodišču levo</translation>
    </message>
    <message>
        <location line="+32"/>
        <source>Top Left</source>
        <translation>Zgoraj levo</translation>
    </message>
    <message>
        <location line="+35"/>
        <source>Base Center</source>
        <translation>V izhodišču sredina</translation>
    </message>
    <message>
        <location line="+32"/>
        <source>Base Right</source>
        <translation>V izhodišču desno</translation>
    </message>
    <message>
        <location line="+32"/>
        <source>Middle Center</source>
        <translation>Sredina center</translation>
    </message>
    <message>
        <location line="+32"/>
        <source>Bottom Right</source>
        <translation>Spodaj desno</translation>
    </message>
    <message>
        <location line="+32"/>
        <source>Middle Left</source>
        <translation>Sredina levo</translation>
    </message>
    <message>
        <location line="+32"/>
        <source>Top Right</source>
        <translation>Zgoraj desno</translation>
    </message>
    <message>
        <location line="+88"/>
        <source>Cancel</source>
        <translation>Prekliči</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>OK</source>
        <translation>Vredu</translation>
    </message>
</context>
</TS>

==> qcad-3.15.2.0.txz: usr/local/share/qcad/scripts/Draw/Text/ts/Text_sl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sl_SI">
<context>
    <name>Dialog</name>
    <message>
        <location filename="../TextDialog/CharacterMapDialog.ui" line="+14"/>
        <source>Character Map</source>
        <translation>Tabela znakov</translation>
    </message>
</context>
<context>
    <name>Text</name>
    <message>
        <location filename="../Text.js" line="+88"/>
        <source>Position</source>
        <translation>Pozicija</translation>
    </message>
    <message>
        <location filename="../Text.ui" line="+17"/>
        <source>Contents:</source>
        <translation>Vsebina:</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Height:</source>
        <translation>Višina:</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Angle:</source>
        <translation>Kot:</translation>
    </message>
    <message>
        <location filename="../TextInit.js" line="+2"/>
        <source>&amp;Text</source>
        <translation>&amp;Besedilo</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Draw text</source>
        <translation>Vstavi besedilo</translation>
    </message>
</context>
<context>
    <name>TextDialog</name>
    <message>
        <location filename="../TextDialog/TextDialog.js" line="+242"/>
        <source>Default value:</source>
        <translation>Privzeta vrednost:</translation>
    </message>
    <message>
        <location line="+260"/>
        <source>&amp;Undo</source>
        <translation>Ra&amp;zveljavi</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>&amp;Redo</source>
        <translation>&amp;Obnovi</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Cu&amp;t</source>
        <translation>&amp;Izreži</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>&amp;Copy</source>
        <translation>Kop&amp;iraj</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>&amp;Paste</source>
        <translation>&amp;Prilepi</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Bold</source>
        <translation>&amp;Krepko</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>&amp;Italic</source>
        <translation>Pošev&amp;no</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>&amp;Subscript</source>
        <translation>Po&amp;dpisano</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>&amp;Superscript</source>
        <translation>&amp;Nadpisano</translation>
    </message>
    <message>
        <location line="+18"/>
        <source>&amp;Color...</source>
        <translation>Bar&amp;va...</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>&amp;Special Characters...</source>
        <translation>Posebni &amp;znaki...</translation>
    </message>
    <message>
        <location line="+310"/>
        <source>Others...</source>
        <translation>Drugo...</translation>
    </message>
    <message>
        <location line="+131"/>
        <source>Degree</source>
        <translation>Stopinje</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Plus-Minus</source>
        <translation>Plus-Minus</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Diameter</source>
        <translation>Premer</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Almost equal</source>
        <translation>Skoraj enako</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Multiplication</source>
        <translation>Moženje</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Division</source>
        <translation>Deljenje</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Delta</source>
        <translation>Delta</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Pi</source>
        <translation>Pi</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Identity</source>
        <translation>Identiteta</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Not equal</source>
        <translation>Ni enako</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Ohm</source>
        <translation>Ohm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Omega</source>
        <translation>Omega</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Squared</source>
        <translation>Kvadrirano</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Cubed</source>
        <translation>Kvadratasto</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>No-break space</source>
        <translation>Brez preloma presledka</translation>
    </message>
    <message>
        <location filename="../TextDialog/TextDialog.ui" line="+14"/>
        <source>Text</source>
        <translation>Besedilo</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Main Font</source>
        <translation>Primarna pisava</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Height:</source>
        <translation>Višina:</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Text Height in Drawing Units</source>
        <translation>Višina besedila v merskih enotah risbe</translation>
    </message>
    <message>
        <location line="+18"/>
        <location line="+213"/>
        <source>Bold</source>
        <translation>Krepko</translation>
    </message>
    <message>
        <location line="-206"/>
        <location line="+219"/>
        <source>Italic</source>
        <translation>Poševno</translation>
    </message>
    <message>
        <location line="-205"/>
        <source>Text fits on one line and has no formatting</source>
        <translation>Besedilo v eni vrstici in brez oblikovanja</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Simple text
(one line, no formatting)</source>
        <translation>Preprosto besedilo
(ena vrstica, brez oblikovanja)</translation>
    </message>
    <message>
        <location line="+21"/>
        <source>Rich Text</source>
        <translation>Obogateno besedilo</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Cut</source>
        <translation>Izreži</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Copy</source>
        <translation>Kopiraj</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Paste</source>
        <translation>Prilepi</translation>
    </message>
    <message>
        <location line="+115"/>
        <source>Ctrl+B</source>
        <translation>Ctrl+B</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Ctrl+I</source>
        <translation>Ctrl+I</translation>
    </message>
    <message>
        <location line="+40"/>
        <source>Insert Symbol...</source>
        <translation>Vstavi simbol...</translation>
    </message>
    <message>
        <location line="+43"/>
        <source>Source</source>
        <translation>Vir</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>Attribute Details</source>
        <translation>Podrobnosti atributa</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Tag:</source>
        <translation>Značka:</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Prompt:</source>
        <translation>Vprašaj:</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Value:</source>
        <translation>Vrednost:</translation>
    </message>
    <message>
        <location line="+42"/>
        <source>Text Geometry</source>
        <translation>Geometrija besedila</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Line spacing factor:</source>
        <translation>Razmak med vrsticami:</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Line Spacing Factor</source>
        <translation>Faktor razmaka med vrsticami</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Angle:</source>
        <translation>Kot:</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Rotation Angle</source>
        <translation>Kot rotacije</translation>
    </message>
    <message>
        <location line="+25"/>
        <source>Alignment</source>
        <translation>Poravnava</translation>
    </message>
    <message>
        <location line="+311"/>
        <source>Bottom Left</source>
        <translation>Desno spodaj</translation>
    </message>
    <message>
        <location line="+29"/>
        <source>Bottom Center</source>
        <translation>Sredina spodaj</translation>
    </message>
    <message>
        <location line="-261"/>
        <source>Top Center</source>
        <translation>Zgoraj sredina</translation>
    </message>
    <message>
        <location line="+29"/>
        <source>Middle Right</source>
        <translation>Sredina desno</translation>
    </message>
    <message>
        <location line="+116"/>
        <source>Base Left</source>
        <translation>V izhodišču levo</translation>
    </message>
    <message>
        <location line="-177"/>
        <source>Top Left</source>
        <translation>Zgoraj levo</translation>
    </message>
    <message>
        <location line="+206"/>
        <source>Base Center</source>
        <translation>V izhodišču sredina</translation>
    </message>
    <message>
        <location line="+29"/>
        <source>Base Right</source>
        <translation>V izhodišču desno</translation>
    </message>
    <message>
        <location line="-116"/>
        <source>Middle Center</source>
        <translation>Sredina center</translation>
    </message>
    <message>
        <location line="+203"/>
        <source>Bottom Right</source>
        <translation>Spodaj desno</translation>
    </message>
    <message>
        <location line="-174"/>
        <source>Middle Left</source>
        <translation>Sredina levo</translation>
    </message>
    <message>
        <location line="-58"/>
        <source>Top Right</source>
        <translation>Zgoraj desno</translation>
    </message>
    <message>
        <location line="+291"/>
        <source>Cancel</source>
        <translation>Prekliči</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>OK</source>
        <translation>Vredu</translation>
    </message>
</context>
</TS>
